@@ -1,12 +1,12 @@
 from textual.app import App, ComposeResult
 from textual.containers import Container, Horizontal
-from textual.widgets import Header, Footer, Static, Button
+from textual.widgets import Button, Footer, Header, Static
 
 QUESTION = "Do you want to learn about Textual CSS?"
 
 
 class ExampleApp(App):
-    CSS_PATH = "dom4.css"
+    CSS_PATH = "dom4.tcss"
 
     def compose(self) -> ComposeResult:
         yield Header()
